Learn R Programming

tidydatatutor (version 0.1.0)

tdt_file: Create a Link to Tidy Data Tutor from an R Code File

Description

Create a Link to Tidy Data Tutor from an R Code File

Usage

tdt_file(file)

Arguments

file

The path to an R code file.

Value

A string with an appropriately formatted URL to Tidy Data Tutor.

Examples

Run this code
# NOT RUN {
r_code_file <- system.file("test", "test-1.R", package = "tidydatatutor")
tdt_file(r_code_file)
# }

Run the code above in your browser using DataLab